indicatortools.Tempo
====================

.. abjad-lineage:: abjad.tools.indicatortools.Tempo.Tempo

.. autoclass:: abjad.tools.indicatortools.Tempo.Tempo

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Tempo.Tempo.duration
      ~abjad.tools.indicatortools.Tempo.Tempo.duration_to_milliseconds
      ~abjad.tools.indicatortools.Tempo.Tempo.is_imprecise
      ~abjad.tools.indicatortools.Tempo.Tempo.list_related_tempos
      ~abjad.tools.indicatortools.Tempo.Tempo.quarters_per_minute
      ~abjad.tools.indicatortools.Tempo.Tempo.rewrite_duration
      ~abjad.tools.indicatortools.Tempo.Tempo.textual_indication
      ~abjad.tools.indicatortools.Tempo.Tempo.units_per_minute
      ~abjad.tools.indicatortools.Tempo.Tempo.__add__
      ~abjad.tools.indicatortools.Tempo.Tempo.__copy__
      ~abjad.tools.indicatortools.Tempo.Tempo.__div__
      ~abjad.tools.indicatortools.Tempo.Tempo.__eq__
      ~abjad.tools.indicatortools.Tempo.Tempo.__format__
      ~abjad.tools.indicatortools.Tempo.Tempo.__ge__
      ~abjad.tools.indicatortools.Tempo.Tempo.__gt__
      ~abjad.tools.indicatortools.Tempo.Tempo.__hash__
      ~abjad.tools.indicatortools.Tempo.Tempo.__le__
      ~abjad.tools.indicatortools.Tempo.Tempo.__lt__
      ~abjad.tools.indicatortools.Tempo.Tempo.__mul__
      ~abjad.tools.indicatortools.Tempo.Tempo.__ne__
      ~abjad.tools.indicatortools.Tempo.Tempo.__repr__
      ~abjad.tools.indicatortools.Tempo.Tempo.__rmul__
      ~abjad.tools.indicatortools.Tempo.Tempo.__str__
      ~abjad.tools.indicatortools.Tempo.Tempo.__sub__
      ~abjad.tools.indicatortools.Tempo.Tempo.__truediv__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Tempo.Tempo.duration
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Tempo.Tempo.is_imprecise
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Tempo.Tempo.quarters_per_minute
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Tempo.Tempo.textual_indication
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Tempo.Tempo.units_per_minute
   :noindex:

Methods
-------

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.duration_to_milliseconds
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.list_related_tempos
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.rewrite_duration
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__add__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__div__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__ge__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__gt__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__le__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__lt__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__mul__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__repr__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__rmul__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__str__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__sub__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Tempo.Tempo.__truediv__
   :noindex:
